@@ -34,6 +34,7 @@
 #'   parent coordinates" or character string. If too short they will be recycled.
 #' @param label.x,label.y \code{numeric} Coordinates (in data units) to be used
 #'   for absolute positioning of the output. If too short they will be recycled.
+#' @param output.type character One of "expression", "LaTex" or "text".
 #'
 #' @note For backward compatibility a logical is accepted as argument for
 #'   \code{eq.with.lhs}, giving the same output than the current default
@@ -88,9 +89,10 @@
 stat_poly_eq <- function(mapping = NULL, data = NULL, geom = "text",
                          formula = NULL,
                          eq.with.lhs = "italic(y)~`=`~",
-                         eq.x.rhs = "~italic(x)",
+                         eq.x.rhs = NULL,
                          label.x.npc = "left", label.y.npc = "top",
                          label.x = NULL, label.y = NULL,
+                         output.type = "expression",
                          position = "identity",
                          na.rm = FALSE, show.legend = FALSE,
                          inherit.aes = TRUE, ...) {
@@ -104,6 +106,7 @@ stat_poly_eq <- function(mapping = NULL, data = NULL, geom = "text",
                   label.y.npc = label.y.npc,
                   label.x = label.x,
                   label.y = label.y,
+                  output.type = output.type,
                   na.rm = na.rm,
                   ...)
   )
@@ -124,32 +127,40 @@ poly_eq_compute_group_fun <- function(data,
                                      label.x.npc,
                                      label.y.npc,
                                      label.x,
-                                     label.y) {
+                                     label.y,
+                                     output.type) {
+  output.type = tolower(output.type)
+  if (is.null(eq.x.rhs) && output.type == "expression") {
+    eq.x.rhs = "~italic(x)"
+  } else {
+    eq.x.rhs = " x"
+  }
   if (length(unique(data$x)) < 2) {
     # Not enough data to perform fit
     return(data.frame())
   }
   group.idx <- abs(data$group[1])
 
+  group.idx <- abs(data$group[1])
   if (length(label.x.npc) >= group.idx) {
     label.x.npc <- label.x.npc[group.idx]
-  } else {
+  } else if (length(label.x.npc) > 0) {
     label.x.npc <- label.x.npc[1]
   }
   if (length(label.y.npc) >= group.idx) {
     label.y.npc <- label.y.npc[group.idx]
-  } else {
+  } else if (length(label.y.npc) > 0) {
     label.y.npc <- label.y.npc[1]
   }
 
   if (length(label.x) >= group.idx) {
     label.x <- label.x[group.idx]
-  } else {
+  } else if (length(label.x) > 0) {
     label.x <- label.x[1]
   }
   if (length(label.y) >= group.idx) {
     label.y <- label.y[group.idx]
-  } else {
+  } else if (length(label.y) > 0) {
     label.y <- label.y[1]
   }
 
@@ -165,11 +176,18 @@ poly_eq_compute_group_fun <- function(data,
   adj.rr <- summary(mf)$adj.r.squared
   eq.char <- as.character(signif(polynom::as.polynomial(coefs), 3))
   eq.char <- gsub("e([+-]?[0-9]*)", "%*%10^\\1", eq.char)
+  if (output.type %in% c("latex", "tex", "tikz")) {
+    eq.char <- gsub("*", " ", eq.char, fixed = TRUE)
+  }
   if (is.character(eq.with.lhs)) {
     lhs <- eq.with.lhs
     eq.with.lhs <- TRUE
   } else if (eq.with.lhs) {
-    lhs <- "italic(y)~`=`~"
+    if (output.type == "expression") {
+      lhs <- "italic(y)~`=`~"
+     } else if (output.type %in% c("latex", "tex", "tikz", "text")) {
+       lhs <- "y = "
+     }
   }
   if (eq.with.lhs) {
     eq.char <- paste(lhs, eq.char, sep = "")
@@ -178,12 +196,21 @@ poly_eq_compute_group_fun <- function(data,
   adj.rr.char <- format(adj.rr, digits = 2)
   AIC.char <- sprintf("%.4g", AIC)
   BIC.char <- sprintf("%.4g", BIC)
-  z <- data.frame(eq.label = gsub("x", eq.x.rhs, eq.char, fixed = TRUE),
-             rr.label = paste("italic(R)^2", rr.char, sep = "~`=`~"),
-             adj.rr.label = paste("italic(R)[adj]^2",
-                                  adj.rr.char, sep = "~`=`~"),
-             AIC.label = paste("AIC", AIC.char, sep = "~`=`~"),
-             BIC.label = paste("BIC", BIC.char, sep = "~`=`~"))
+  if (output.type == "expression") {
+    z <- data.frame(eq.label = gsub("x", eq.x.rhs, eq.char, fixed = TRUE),
+                    rr.label = paste("italic(R)^2", rr.char, sep = "~`=`~"),
+                    adj.rr.label = paste("italic(R)[adj]^2",
+                                         adj.rr.char, sep = "~`=`~"),
+                    AIC.label = paste("AIC", AIC.char, sep = "~`=`~"),
+                    BIC.label = paste("BIC", BIC.char, sep = "~`=`~"))
+  } else if (output.type %in% c("latex", "tex", "text")) {
+    z <- data.frame(eq.label = gsub("x", eq.x.rhs, eq.char, fixed = TRUE),
+                    rr.label = paste("R^2", rr.char, sep = " = "),
+                    adj.rr.label = paste("R_{adj}^2",
+                                         adj.rr.char, sep = " = "),
+                    AIC.label = paste("AIC", AIC.char, sep = " = "),
+                    BIC.label = paste("BIC", BIC.char, sep = " = "))
+  }
 
   if (length(label.x) > 0) {
     z$x <- label.x
@@ -215,7 +242,7 @@ poly_eq_compute_group_fun <- function(data,
   }
 
   if (length(label.y) > 0) {
-    z$x <- label.y
+    z$y <- label.y
     z$vjust <- 0.5
   } else if (length(label.y.npc) > 0) {
     if (is.numeric(label.y.npc)) {
@@ -223,15 +250,15 @@ poly_eq_compute_group_fun <- function(data,
         warning("'label.y.npc' argument is numeric but outside range 0..1.")
       }
       z$y <- scales$y$dimension()[1] + label.y.npc *
-        diff(scales$y$dimension())
-      z$vjust <- 1.4 * group.idx - (0.7 * length(group.idx))
+        (scales$y$dimension()[2] - scales$y$dimension()[1])
+      z$vjust <- 1.4 * (group.idx - 1) - (0.7 * (length(group.idx) - 1))
     } else if (is.character(label.y.npc)) {
       if (label.y.npc == "bottom") {
         z$y <- scales$y$dimension()[1]
         z$vjust <- -1.4 * group.idx
       } else if (label.y.npc %in% c("center", "centre", "middle")) {
         z$y <- mean(scales$y$dimension())
-        z$vjust <- 1.4 * group.idx - (0.7 * length(group.idx))
+        z$vjust <- 1.4 * (group.idx - 1) - (0.7 * (length(group.idx) - 1))
       } else if (label.y.npc == "top") {
         z$y <- scales$y$dimension()[2]
         z$vjust <- 1.4 * group.idx
